.. SPDX-FileCopyrightText: 2023 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: CC0-1.0

API Reference
=============

.. autosummary::
    :toctree: api

    repology_client
    repology_client.constants
    repology_client.exceptions
    repology_client.types
    repology_client.utils
